@@ -3,12 +3,16 @@ from __future__ import print_function, unicode_literals
 import logging
 import os
 import sys
+import warnings
+
+# Filter annoying warnings from argh about bash completion
+warnings.filterwarnings('ignore', '.*argcomplete.*')
 
 from argh import arg, ArghParser
 
 from .gantry import Gantry, GantryError, DOCKER_DEFAULT_URL
 
-_log_level_default = logging.WARN
+_log_level_default = logging.INFO
 _log_level = getattr(logging,
                      os.environ.get('GANTRY_LOGLEVEL', '').upper(),
                      _log_level_default)
